#
# spec file for package arc-gtk-theme
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _theme  Arc
%define _name   arc
Name:           arc-gtk-theme
Version:        20200502
Release:        lp152.1.1
Summary:        Arc GTK theme
License:        GPL-3.0-or-later
URL:            https://github.com/jnsh/arc-theme
Source:         %{_name}-theme-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cinnamon
BuildRequires:  fdupes
BuildRequires:  gnome-shell
BuildRequires:  inkscape
BuildRequires:  optipng
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  pkgconfig(gtk+-3.0)
BuildArch:      noarch

%description
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

%package -n metatheme-%{_name}-common
Summary:        Arc Common Theme Files
Recommends:     adwaita-icon-theme
Suggests:       gtk2-metatheme-%{_name} = %{version}
Suggests:       gtk3-metatheme-%{_name} = %{version}

%description -n metatheme-%{_name}-common
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains common files and themes for GNOME Shell,
Marco, Xfwm4, and Cinnamon.

%package -n gtk2-metatheme-%{_name}
Summary:        Arc GTK 2 Theme
Requires:       gtk2-engine-murrine
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    (metatheme-%{_name}-common and gtk2)

%description -n gtk2-metatheme-%{_name}
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains the GTK 2 theme.

%package -n gtk3-metatheme-%{_name}
Summary:        Arc GTK 3 Theme
Requires:       gtk3
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    (metatheme-%{_name}-common and gtk3)

%description -n gtk3-metatheme-%{_name}
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains the GTK 3 theme.

%prep
%setup -q -n %{_name}-theme-%{version}
sed -i '/configure/d' autogen.sh
sed -i 's/^\(IconTheme=\).*$/\1Adwaita/' common/index/*/index.theme

%build
./autogen.sh
%configure
%make_build

%install
%make_install
find %{buildroot}%{_datadir}/ -type f -name '*.sh' -delete
%fdupes %{buildroot}%{_datadir}/

%files -n metatheme-%{_name}-common
%license COPYING
%doc AUTHORS README.md
%dir %{_datadir}/themes/%{_theme}*/
%exclude %{_datadir}/themes/%{_theme}*/gtk-?.0/
%{_datadir}/themes/%{_theme}*/*

%files -n gtk2-metatheme-%{_name}
%license COPYING
%doc AUTHORS README.md
%{_datadir}/themes/%{_theme}*/gtk-2.0/

%files -n gtk3-metatheme-%{_name}
%license COPYING
%doc AUTHORS README.md
%{_datadir}/themes/%{_theme}*/gtk-3.0/

%changelog
* Thu May  7 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 20200502:
  * No changelog available.
- Build the Cinnamon theme.
- Switch to https://github.com/jnsh/arc-theme
* Tue Nov 19 2019 Petr Cervinka <petr@cervinka.net>
- Update to version 20190917:
  * Allow builds against gnome-shell 3.34
  * Refactor gnome-shell 3.32 code
  * Removes redundant selectors/styling (i.e. styling that is no longer
    required in newer gnome shell versions), and replaces with newer selectors/styling
    (modifying to match Arc styling where necessary)
  * Integrates styling from the default gnome shell theme into the Arc shell theme.
    Because the user shell theme (Arc in this case) is "overlaid" over the default shell
    theme, this is styling that was being "pulled in" anyway.
  * Add full shadows to panel dropdown menus
  * InfoBar colors should respect type
  * Remove border from stackswitcher
  * Don't hardcode LightDM font-size
  * XFCE 4.14 panel styling fixes
- Update GitHub project url from NicoHood to arc-design
- Update public keyring from  NicoHood <pgp@nicohood.de> to David Mohammed <fossfreedom@ubuntu.com>
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat May 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 20190330 (no changelog supplied)
- Fix build with gnome-shell 3.32 and newer
* Thu Oct 25 2018 sor.alexei@meowr.ru
- Update to version 20181022:
  * No changelog available.
- Use GPG signing.
* Mon Sep 10 2018 minava@t-online.de
- Update to version 20180715 (changes since 20180114):
  * Added openbox theme
  * Updated thunar style
  * Added inkscape and optipng dependencies
  * Bugfixes
* Thu May 31 2018 mati865@gmail.com
- Update to version 20180114
  * General cleanup of outdated gtk versions and extras
  * Readme update
  * Minor fixes for cinnamon and xfce4
  * Add budgie desktop styling #17
  * Slightly darken fonts for light theme to improve contrast #15
  * Switch building from gulp to sassc
  * Mate screensaver styling #27
  * Install plank theme with makefile directly
* Sun Mar 12 2017 matthias.eliasson@gmail.com
- Update to version 20170302
  * Cinnamon 3.2 fixes
  * Fix frame borders with GTK 3.22.9
  * Small bugfixes
* Tue Nov 22 2016 sor.alexei@meowr.ru
- Update to version 20161119:
  * Cinnamon 3.2 support.
  * Bugfixes.
* Sun Nov 13 2016 mailaender@opensuse.org
- Update to version 20161005
  * Fix OSD windows in MATE 1.16
  * Fix Unity window decorations with GTK 3.20
  * Minor bugfixes
* Sat Sep 24 2016 sor.alexei@meowr.ru
- Update to version 20160923:
  * GNOME 3.22 support.
  * elementary OS Loki support.
  * Improve GNOME Flashback support (3.20+ only).
  * Easier window resizing in Xfce and MATE.
  * Bugfixes.
* Sun Jun  5 2016 sor.alexei@meowr.ru
- Update to version 20160605 (changes since 20160331):
  * Use highlight colour for selected menuitems.
  * Add dark Chromium theme.
  * Merge xfce-notify theme with GTK+ 2 theme (this removes the
  - -disable-xfce-notify build option).
  * Fix bugs in GTK+ 2 entry styling.
  * Update Unity window decorations.
  * Bugfixes.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 20160331:
  * Lots of fixes for Gnome/GTK+ 3.20.
* Fri Mar 25 2016 sor.alexei@meowr.ru
- Initial package.
